==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/HTTPFaultInjectionFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class HTTPFaultInjectionFluentImpl<A extends HTTPFaultInjectionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HTTPFaultInjectionFluent<A>{

    private AbortBuilder abort;
    private DelayBuilder delay;

    public HTTPFaultInjectionFluentImpl(){
    }
    public HTTPFaultInjectionFluentImpl(HTTPFaultInjection instance){
            this.withAbort(instance.getAbort()); 
            this.withDelay(instance.getDelay()); 
    }

    
/**
 * This method has been deprecated, please use method buildAbort instead.
 * @return The buildable object.
 */
@Deprecated public Abort getAbort(){
            return this.abort!=null?this.abort.build():null;
    }

    public Abort buildAbort(){
            return this.abort!=null?this.abort.build():null;
    }

    public A withAbort(Abort abort){
            _visitables.remove(this.abort);
            if (abort!=null){ this.abort= new AbortBuilder(abort); _visitables.add(this.abort);} return (A) this;
    }

    public Boolean hasAbort(){
            return this.abort != null;
    }

    public HTTPFaultInjectionFluent.AbortNested<A> withNewAbort(){
            return new AbortNestedImpl();
    }

    public HTTPFaultInjectionFluent.AbortNested<A> withNewAbortLike(Abort item){
            return new AbortNestedImpl(item);
    }

    public HTTPFaultInjectionFluent.AbortNested<A> editAbort(){
            return withNewAbortLike(getAbort());
    }

    public HTTPFaultInjectionFluent.AbortNested<A> editOrNewAbort(){
            return withNewAbortLike(getAbort() != null ? getAbort(): new AbortBuilder().build());
    }

    public HTTPFaultInjectionFluent.AbortNested<A> editOrNewAbortLike(Abort item){
            return withNewAbortLike(getAbort() != null ? getAbort(): item);
    }

    
/**
 * This method has been deprecated, please use method buildDelay instead.
 * @return The buildable object.
 */
@Deprecated public Delay getDelay(){
            return this.delay!=null?this.delay.build():null;
    }

    public Delay buildDelay(){
            return this.delay!=null?this.delay.build():null;
    }

    public A withDelay(Delay delay){
            _visitables.remove(this.delay);
            if (delay!=null){ this.delay= new DelayBuilder(delay); _visitables.add(this.delay);} return (A) this;
    }

    public Boolean hasDelay(){
            return this.delay != null;
    }

    public HTTPFaultInjectionFluent.DelayNested<A> withNewDelay(){
            return new DelayNestedImpl();
    }

    public HTTPFaultInjectionFluent.DelayNested<A> withNewDelayLike(Delay item){
            return new DelayNestedImpl(item);
    }

    public HTTPFaultInjectionFluent.DelayNested<A> editDelay(){
            return withNewDelayLike(getDelay());
    }

    public HTTPFaultInjectionFluent.DelayNested<A> editOrNewDelay(){
            return withNewDelayLike(getDelay() != null ? getDelay(): new DelayBuilder().build());
    }

    public HTTPFaultInjectionFluent.DelayNested<A> editOrNewDelayLike(Delay item){
            return withNewDelayLike(getDelay() != null ? getDelay(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HTTPFaultInjectionFluentImpl that = (HTTPFaultInjectionFluentImpl) o;
            if (abort != null ? !abort.equals(that.abort) :that.abort != null) return false;
            if (delay != null ? !delay.equals(that.delay) :that.delay != null) return false;
            return true;
    }


    public class AbortNestedImpl<N> extends AbortFluentImpl<HTTPFaultInjectionFluent.AbortNested<N>> implements HTTPFaultInjectionFluent.AbortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final AbortBuilder builder;
    
            AbortNestedImpl(Abort item){
                    this.builder = new AbortBuilder(this, item);
            }
            AbortNestedImpl(){
                    this.builder = new AbortBuilder(this);
            }
    
    public N and(){
            return (N) HTTPFaultInjectionFluentImpl.this.withAbort(builder.build());
    }
    public N endAbort(){
            return and();
    }

}
    public class DelayNestedImpl<N> extends DelayFluentImpl<HTTPFaultInjectionFluent.DelayNested<N>> implements HTTPFaultInjectionFluent.DelayNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final DelayBuilder builder;
    
            DelayNestedImpl(Delay item){
                    this.builder = new DelayBuilder(this, item);
            }
            DelayNestedImpl(){
                    this.builder = new DelayBuilder(this);
            }
    
    public N and(){
            return (N) HTTPFaultInjectionFluentImpl.this.withDelay(builder.build());
    }
    public N endDelay(){
            return and();
    }

}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/HTTPFaultInjectionFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class HTTPFaultInjectionFluentImpl<A extends HTTPFaultInjectionFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HTTPFaultInjectionFluent<A>{

    private AbortBuilder abort;
    private DelayBuilder delay;

    public HTTPFaultInjectionFluentImpl(){
    }
    public HTTPFaultInjectionFluentImpl(HTTPFaultInjection instance){
            this.withAbort(instance.getAbort()); 
            this.withDelay(instance.getDelay()); 
    }

    
/**
 * This method has been deprecated, please use method buildAbort instead.
 * @return The buildable object.
 */
@Deprecated public Abort getAbort(){
            return this.abort!=null?this.abort.build():null;
    }

    public Abort buildAbort(){
            return this.abort!=null?this.abort.build():null;
    }

    public A withAbort(Abort abort){
            _visitables.get("abort").remove(this.abort);
            if (abort!=null){ this.abort= new AbortBuilder(abort); _visitables.get("abort").add(this.abort);} return (A) this;
    }

    public Boolean hasAbort(){
            return this.abort != null;
    }

    public HTTPFaultInjectionFluent.AbortNested<A> withNewAbort(){
            return new AbortNestedImpl();
    }

    public HTTPFaultInjectionFluent.AbortNested<A> withNewAbortLike(Abort item){
            return new AbortNestedImpl(item);
    }

    public HTTPFaultInjectionFluent.AbortNested<A> editAbort(){
            return withNewAbortLike(getAbort());
    }

    public HTTPFaultInjectionFluent.AbortNested<A> editOrNewAbort(){
            return withNewAbortLike(getAbort() != null ? getAbort(): new AbortBuilder().build());
    }

    public HTTPFaultInjectionFluent.AbortNested<A> editOrNewAbortLike(Abort item){
            return withNewAbortLike(getAbort() != null ? getAbort(): item);
    }

    
/**
 * This method has been deprecated, please use method buildDelay instead.
 * @return The buildable object.
 */
@Deprecated public Delay getDelay(){
            return this.delay!=null?this.delay.build():null;
    }

    public Delay buildDelay(){
            return this.delay!=null?this.delay.build():null;
    }

    public A withDelay(Delay delay){
            _visitables.get("delay").remove(this.delay);
            if (delay!=null){ this.delay= new DelayBuilder(delay); _visitables.get("delay").add(this.delay);} return (A) this;
    }

    public Boolean hasDelay(){
            return this.delay != null;
    }

    public HTTPFaultInjectionFluent.DelayNested<A> withNewDelay(){
            return new DelayNestedImpl();
    }

    public HTTPFaultInjectionFluent.DelayNested<A> withNewDelayLike(Delay item){
            return new DelayNestedImpl(item);
    }

    public HTTPFaultInjectionFluent.DelayNested<A> editDelay(){
            return withNewDelayLike(getDelay());
    }

    public HTTPFaultInjectionFluent.DelayNested<A> editOrNewDelay(){
            return withNewDelayLike(getDelay() != null ? getDelay(): new DelayBuilder().build());
    }

    public HTTPFaultInjectionFluent.DelayNested<A> editOrNewDelayLike(Delay item){
            return withNewDelayLike(getDelay() != null ? getDelay(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            HTTPFaultInjectionFluentImpl that = (HTTPFaultInjectionFluentImpl) o;
            if (abort != null ? !abort.equals(that.abort) :that.abort != null) return false;
            if (delay != null ? !delay.equals(that.delay) :that.delay != null) return false;
            return true;
    }


    public class AbortNestedImpl<N> extends AbortFluentImpl<HTTPFaultInjectionFluent.AbortNested<N>> implements HTTPFaultInjectionFluent.AbortNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final AbortBuilder builder;
    
            AbortNestedImpl(Abort item){
                    this.builder = new AbortBuilder(this, item);
            }
            AbortNestedImpl(){
                    this.builder = new AbortBuilder(this);
            }
    
    public N and(){
            return (N) HTTPFaultInjectionFluentImpl.this.withAbort(builder.build());
    }
    public N endAbort(){
            return and();
    }

}
    public class DelayNestedImpl<N> extends DelayFluentImpl<HTTPFaultInjectionFluent.DelayNested<N>> implements HTTPFaultInjectionFluent.DelayNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final DelayBuilder builder;
    
            DelayNestedImpl(Delay item){
                    this.builder = new DelayBuilder(this, item);
            }
            DelayNestedImpl(){
                    this.builder = new DelayBuilder(this);
            }
    
    public N and(){
            return (N) HTTPFaultInjectionFluentImpl.this.withDelay(builder.build());
    }
    public N endDelay(){
            return and();
    }

}


}
